@@ -5,6 +5,7 @@ pub mod redact;
 use crate::keys::{Key, KeyCollection};
 use async_trait::async_trait;
 use error::StorageError;
+use std::{ops::Deref, sync::Arc};
 
 /// The operations a storer of `Key` structs must be able to fulfill.
 #[async_trait]
@@ -17,6 +18,26 @@ pub trait KeyStorer: Clone + Send + Sync {
     async fn create(&self, value: Key) -> Result<bool, StorageError>;
 }
 
+/// Allows an `Arc<KeyStorer>` to act exactly like a `KeyStorer`, dereferencing
+/// itself and passing calls through to the underlying `KeyStorer`.
+#[async_trait]
+impl<U> KeyStorer for Arc<U>
+where
+    U: KeyStorer,
+{
+    async fn get(&self, path: &str) -> Result<Key, StorageError> {
+        self.deref().get(path).await
+    }
+
+    async fn list(&self) -> Result<KeyCollection, StorageError> {
+        self.deref().list().await
+    }
+
+    async fn create(&self, value: Key) -> Result<bool, StorageError> {
+        self.deref().create(value).await
+    }
+}
+
 pub mod tests {
     use crate::{Key, KeyCollection, KeyStorer, StorageError};
     use async_trait::async_trait;
